@@ -50,12 +50,12 @@ export class AssertionError extends Error {
 		// use the values for custom diff views
 		this.raw = options.raw;
 
-		this.savedError = options.savedError ? options.savedError : getErrorWithLongStackTrace();
+		this.savedError = options.savedError || getErrorWithLongStackTrace();
 	}
 }
 
 export function checkAssertionMessage(assertion, message) {
-	if (typeof message === 'undefined' || typeof message === 'string') {
+	if (message === undefined || typeof message === 'string') {
 		return true;
 	}
 
@@ -143,14 +143,17 @@ function validateExpectations(assertion, expectations, numberArgs) { // eslint-d
 				case 'is':
 				case 'message':
 				case 'name':
-				case 'code':
+				case 'code': {
 					continue;
-				default:
+				}
+
+				default: {
 					throw new AssertionError({
 						assertion,
 						message: `The second argument to \`t.${assertion}()\` contains unexpected properties`,
 						values: [formatWithLabel('Called with:', expectations)],
 					});
+				}
 			}
 		}
 	}
@@ -250,7 +253,7 @@ function assertExpectations({assertion, actual, expectations, message, prefix, s
 		});
 	}
 
-	if (typeof expectations.code !== 'undefined' && actual.code !== expectations.code) {
+	if (expectations.code !== undefined && actual.code !== expectations.code) {
 		throw new AssertionError({
 			assertion,
 			message,
