@@ -166,7 +166,8 @@ let signalAvailable = () => {
 };
 
 let fatal;
-loadFactory(workerData.filename).then(factory => {
+try {
+	const factory = await loadFactory(workerData.filename);
 	if (typeof factory !== 'function') {
 		throw new TypeError(`Missing default factory function export for shared worker plugin at ${workerData.filename}`);
 	}
@@ -236,14 +237,12 @@ loadFactory(workerData.filename).then(factory => {
 			};
 		},
 	});
-}).catch(error => {
-	if (fatal === undefined) {
-		fatal = error;
-	}
-}).finally(() => {
+} catch (error) {
+	fatal = fatal ?? error;
+} finally {
 	if (fatal !== undefined) {
 		process.nextTick(() => {
 			throw fatal;
 		});
 	}
-});
+}
