@@ -153,26 +153,38 @@ export default class TapReporter {
 		const fileStats = this.stats && evt.testFile ? this.stats.byFile.get(evt.testFile) : null;
 
 		switch (evt.type) {
-			case 'declared-test':
+			case 'declared-test': {
 				// Ignore
 				break;
-			case 'hook-failed':
+			}
+
+			case 'hook-failed': {
 				this.writeTest(evt, {passed: false, todo: false, skip: false});
 				break;
-			case 'hook-finished':
+			}
+
+			case 'hook-finished': {
 				this.writeComment(evt, {});
 				break;
-			case 'internal-error':
+			}
+
+			case 'internal-error': {
 				this.writeCrash(evt);
 				break;
-			case 'missing-ava-import':
+			}
+
+			case 'missing-ava-import': {
 				this.filesWithMissingAvaImports.add(evt.testFile);
 				this.writeCrash(evt, `No tests found in ${this.relativeFile(evt.testFile)}, make sure to import "ava" at the top of your test file`);
 				break;
-			case 'process-exit':
+			}
+
+			case 'process-exit': {
 				this.writeProcessExit(evt);
 				break;
-			case 'selected-test':
+			}
+
+			case 'selected-test': {
 				if (evt.skip) {
 					this.writeTest(evt, {passed: true, todo: false, skip: true});
 				} else if (evt.todo) {
@@ -180,25 +192,39 @@ export default class TapReporter {
 				}
 
 				break;
-			case 'stats':
+			}
+
+			case 'stats': {
 				this.stats = evt.stats;
 				break;
-			case 'test-failed':
+			}
+
+			case 'test-failed': {
 				this.writeTest(evt, {passed: false, todo: false, skip: false});
 				break;
-			case 'test-passed':
+			}
+
+			case 'test-passed': {
 				this.writeTest(evt, {passed: true, todo: false, skip: false});
 				break;
-			case 'timeout':
+			}
+
+			case 'timeout': {
 				this.writeTimeout(evt);
 				break;
-			case 'uncaught-exception':
+			}
+
+			case 'uncaught-exception': {
 				this.writeCrash(evt);
 				break;
-			case 'unhandled-rejection':
+			}
+
+			case 'unhandled-rejection': {
 				this.writeCrash(evt);
 				break;
-			case 'worker-failed':
+			}
+
+			case 'worker-failed': {
 				if (!this.filesWithMissingAvaImports.has(evt.testFile)) {
 					if (evt.nonZeroExitCode) {
 						this.writeCrash(evt, `${this.relativeFile(evt.testFile)} exited with a non-zero exit code: ${evt.nonZeroExitCode}`);
@@ -208,7 +234,9 @@ export default class TapReporter {
 				}
 
 				break;
-			case 'worker-finished':
+			}
+
+			case 'worker-finished': {
 				if (!evt.forcedExit && !this.filesWithMissingAvaImports.has(evt.testFile)) {
 					if (fileStats.declaredTests === 0) {
 						this.writeCrash(evt, `No tests found in ${this.relativeFile(evt.testFile)}`);
@@ -218,12 +246,17 @@ export default class TapReporter {
 				}
 
 				break;
+			}
+
 			case 'worker-stderr':
-			case 'worker-stdout':
+			case 'worker-stdout': {
 				this.stdStream.write(evt.chunk);
 				break;
-			default:
+			}
+
+			default: {
 				break;
+			}
 		}
 	}
 }
