@@ -16,7 +16,7 @@ export function execCli(args, options, cb) {
 		dirname = path.resolve(__dirname, '..', 'fixture');
 		env = {};
 	} else {
-		dirname = path.resolve(__dirname, '..', options.dirname ? options.dirname : 'fixture');
+		dirname = path.resolve(__dirname, '..', options.dirname || 'fixture');
 		env = options.env || {};
 	}
 
