@@ -15,12 +15,12 @@ test('node assertion failures are reported to the console when running in a term
 	const result = await t.throwsAsync(fixture(['assert-failure.js'], options));
 	const error = result.stats.getError(result.stats.failed[0]);
 
-	t.true(error.values.every(value => value.formatted.includes('AssertionError')));
+	t.true(error.values.every(value => value.label.includes('Assertion failed')));
 });
 
 test('node assertion failures are reported to the console when not running in a terminal', async t => {
 	const result = await t.throwsAsync(fixture(['assert-failure.js']));
 	const error = result.stats.getError(result.stats.failed[0]);
 
-	t.true(error.values.every(value => value.formatted.includes('AssertionError')));
+	t.true(error.values.every(value => value.label.includes('Assertion failed')));
 });
